-----------------------------------------------------------------------------------------------
-- Client Lua Script for SlimConfirm
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Apollo"
require "GameLib"
require "Window"
require "Unit"
require "CSIsLib" 

-------------------------------------------------------------------------------------
-- SlimConfirm Module Definition
-----------------------------------------------------------------------------------------------
local SlimConfirm = {}
local runOnce = true
local ok = 0
local csiAddon = Apollo.GetAddon("CSI")
local interactKey = GameLib.GetKeyBinding("Interact")
local mountKey = GameLib.GetKeyBinding("Mount")
local closeWnd


local translateKey = -- Thanks to Durveg for this
{
	["Backspace"] =               "8",
	["Tab"] =                     "9",
	["Enter"] =                   "13",
	["Shift"] =                   "16",
	["Control"] =                 "17",
	["Break"] =                   "19",
	["CapsLock"] =                "20",
	["Esc"] =                     "27",
	["Space"] =                   "32",
	["End"] =                     "35",
	["Home"] =                    "36",
	["Left"] =                    "37",
	["Up"] =                      "38",
	["Right"] =                   "39",
	["Down"] =                    "40",
	["Insert"] =                  "45",
	["Delete"] =                  "46",	
	["1"] =                       "49",
	["2"] =                       "50",	
	["3"] =                       "51",	
	["4"] =                       "52",
	["5"] =                       "53",
	["6"] =                       "54",
	["7"] =                       "55",
	["8"] =                       "56",
	["9"] =                       "57",
	["0"] =                       "48",
	["Q"] =                       "81",
	["W"] =                       "87",
	["E"] =                       "69",
	["R"] =                       "82",
	["T"] =                       "84",
	["Y"] =                       "89",
	["U"] =                       "85",
	["I"] =                       "73",
	["O"] =                       "79",
	["P"] =                       "80",
	["A"] =                       "65",
	["S"] =                       "83",
	["D"] =                       "68",
	["F"] =                       "70",
	["G"] =                       "71",
	["H"] =                       "72",
	["J"] =                       "74",
	["K"] =                       "75",
	["L"] =                       "76",
	["Z"] =                       "90",
	["X"] =                       "88",
	["C"] =                       "67",
	["V"] =                       "86",
	["B"] =                       "66",
	["N"] =                       "78",
	["M"] =                       "77",
	["Page Up"] =                 "33",
	["Page Down"] =               "34",
	  
}

-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function SlimConfirm:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    return o
end

function SlimConfirm:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {"CSI"}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 
-----------------------------------------------------------------------------------------------
-- SlimConfirm OnLoad
-----------------------------------------------------------------------------------------------
function SlimConfirm:OnLoad()
	Apollo.RegisterTimerHandler("OneSecTimer", "OnTimer", self)	
	Apollo.RegisterEventHandler("SystemKeyDown", "KeyDown", self)
end

function SlimConfirm:OnTimer()
	if runOnce == true then
		if csiAddon ~= nil then
			csiAddon.BuildYesNo = self.BuildYesNo
			--Print("SlimConfirm loaded")
			ok = ok + 1
		end
		if ok == 1 then
			runOnce = false
		else
			ok = 0
		end	
	end	
end

function SlimConfirm:KeyDown(Key)
	local tCSI = CSIsLib.GetActiveCSI()
	if tCSI and CSIsLib.IsCSIRunning() then
		local tActiveCSI = CSIsLib.GetActiveCSI()
		local eType = tActiveCSI.eType
		if eType == CSIsLib.ClientSideInteractionType_YesNo then
			if Key == tonumber(translateKey[GameLib.GetKeyBinding("Interact")]) then
			--Print("Key Interact pressed "..translateKey[GameLib.GetKeyBinding("Interact")])
			CSIsLib.CSIProcessInteraction(true)
			closeWnd = true
			elseif Key == tonumber(translateKey[GameLib.GetKeyBinding("Mount")]) then
			--Print("Key Mount pressed "..translateKey[GameLib.GetKeyBinding("Mount")])
			CSIsLib.CSIProcessInteraction(false)
			end
		end	
	end	
end

function SlimConfirm:BuildYesNo(tActiveCSI, bShow)
	if not bShow then 
		return 
	end

	wndCurr = Apollo.LoadForm(self.xmlDoc, "CSI_YesNo", nil, self)
	
	if closeWnd then
		wndCurr:Destroy()
		closeWnd = false
		return
	end
	
	wndCurr:FindChild("NoButton"):SetOpacity(0.9)
	wndCurr:FindChild("YesButton"):SetOpacity(0.9)
	wndCurr:FindChild("CloseButton"):SetOpacity(0.9)
	wndCurr:FindChild("BGArt"):SetSprite("BK3:sprGradientOutwards")
	wndCurr:FindChild("BGArt"):SetBGColor("UI_AlphaPercent65")
	wndCurr:FindChild("NoButton"):SetText("("..(GameLib.GetKeyBinding("Mount"))..") No")
	wndCurr:FindChild("YesButton"):SetText("("..(GameLib.GetKeyBinding("Interact"))..") Yes")
	wndCurr:FindChild("NoButton"):SetData(wndCurr)
	wndCurr:FindChild("YesButton"):SetData(wndCurr)
	wndCurr:FindChild("CloseButton"):SetData(wndCurr)

	
	if tActiveCSI.strContext then
		wndCurr:FindChild("BodyText"):SetText(tActiveCSI.strContext)
	end

	if self.locYesNoLocation then
		wndCurr:MoveToLocation(self.locYesNoLocation)
	end
	self.wndProgress = wndCurr
	
end


-----------------------------------------------------------------------------------------------
-- SlimConfirm Instance
-----------------------------------------------------------------------------------------------
local SlimConfirmInst = SlimConfirm:new()
SlimConfirmInst:Init()
